@@ -1,4 +1,4 @@
-from iosdebug.constants import RUN_SCRIPT_PHASE_ID
+from iosdebug.constants import RUN_SCRIPT_PHASE_ID, SYNC_RUN_SCRIPT_FILE
 import os
 import re
 
@@ -30,8 +30,11 @@ import os
 from iosdebug.stop import stop
 from iosdebug.start import start
 
-if os.environ['ENABLE_PREVIEWS'] == "YES":
-    raise SystemExit
+try:
+    if os.environ['ENABLE_PREVIEWS'] == "YES":
+        raise SystemExit
+except KeyError:
+    pass
 
 stop(update_project=False)
 start(update_project=False)
@@ -39,6 +42,7 @@ start(update_project=False)
 
 
 def add_run_script_build_phase(path):
+    print("Adding run script build phase...")
     files = os.listdir(path)
     xcodeproj_file_name = [file for file in files if ".xcodeproj" in file][0]
     project_file = path + os.sep + xcodeproj_file_name + os.sep + "project.pbxproj"
@@ -84,5 +88,7 @@ def add_run_script_build_phase(path):
     with open(project_file, "w") as file:
         file.write(content)
 
-    with open(".ios-debug_sync.py", "w") as file:
+    with open(SYNC_RUN_SCRIPT_FILE, "w") as file:
         file.write(RUN_SCRIPT_BUILD_PHASE)
+
+    print("Run script build phase added.")
\ No newline at end of file
