@@ -5,6 +5,7 @@ def get_original_registrations(path_to_content_map, protocol_to_protocol_functio
     files = list(path_to_content_map.values())
     result = {}
     for protocol in protocol_to_protocol_functions:
+        print("Looking for original registration for protocol", protocol + "...")
         for file in files:
             if "register(" + protocol in file:
                 registration = re.findall(
@@ -12,4 +13,5 @@ def get_original_registrations(path_to_content_map, protocol_to_protocol_functio
                 )[0].replace(protocol + ".self", protocol + "Impl.self")
 
                 result[protocol] = registration
+    print("Original registrations found.")
     return result
